Module group

Module group 

All expression group definitions.

Macros

define_determiner_with_no_group
Creates GroupDeterminer with no Combinator and provided tokens.
define_group_determiner
Creates GroupDeterminer with given (Combinator => tokens => length => ?Check parsed tokens? (optional bool))
define_group_determiners
Creates GroupDeterminer for given Combinators with provided tokens.
define_tokens_checker
Creates function which checks if ParseStream next values are provided tokens.

Structs

ActionGroup
Combinator with configuration.
ExprGroup
Action with Expr of type either Process, Initial or Err.
GroupDeterminer
GroupDeterminer is used to determine any Combinator or separator (for ex. ,) in ParseStream

Enums

ApplicationType
ApplicationType defines two types of action: Instant and Deferred. Instant means that action will be applied instantly, deferred means that it will wait for all actions in current step to be finished.
Combinator
Combinator is an enum of all possible ProcessExpr, ErrExpr and InitialExpr operations. Used to express group which was found in input ParseStream.
MoveType
MoveType defines nested combinator types.

Type Aliases

CheckStreamFn