pub enum Combinator {
Show 23 variants
Map,
Dot,
Filter,
Inspect,
Then,
AndThen,
Or,
OrElse,
MapErr,
Initial,
Chain,
Flatten,
Collect,
Enumerate,
Find,
Fold,
TryFold,
Unzip,
Zip,
Partition,
FilterMap,
FindMap,
UNWRAP,
}Expand description
Combinator is an enum of all possible ProcessExpr, ErrExpr and InitialExpr operations.
Used to express group which was found in input ParseStream.
Variants
Map
Dot
Filter
Inspect
Then
AndThen
Or
OrElse
MapErr
Initial
Chain
Flatten
Collect
Enumerate
Find
Fold
TryFold
Unzip
Zip
Partition
FilterMap
FindMap
UNWRAP
UNWRAP (Special Combinator used to define that next group position is by one level up - which will be #value.and_then(#previous_expr).#next_expr )
Implementations
Sourceimpl Combinator
Defines group type predicates and parser functions.
impl Combinator
Defines group type predicates and parser functions.
Sourcepub fn is_process_expr(self) -> bool
pub fn is_process_expr(self) -> bool
Returns true if self command group is of ProcessExpr type.
Sourcepub fn is_err_expr(self) -> bool
pub fn is_err_expr(self) -> bool
Returns true if self command group is of ErrExpr type.
Sourcepub fn is_initial_expr(self) -> bool
pub fn is_initial_expr(self) -> bool
Returns true if self command group is of InitialExpr type.
Sourcepub fn can_be_wrapper(self) -> bool
pub fn can_be_wrapper(self) -> bool
Returns true if command group can be a wrapper.