GroupDeterminer

Struct GroupDeterminer 

pub struct GroupDeterminer { /* private fields */ }
GroupDeterminer is used to determine any Combinator or separator (for ex. ,) in ParseStream

Implementations

Source

impl GroupDeterminer

pub const fn new_const( combinator: Option<Combinator>, check_input_fn: *const (), validate_parsed: bool, length: u8, ) -> Self

Constructs new GroupDeterminer using const fn (can be used to create const or static item).

Example:
extern crate join_impl;
extern crate syn;

use syn::Token;
use syn::parse::ParseStream;
use join_impl::chain::group::GroupDeterminer;

fn check_input(input: ParseStream) -> bool { input.peek(Token![,]) }

let first_comma_determiner = GroupDeterminer::new_const(
    None, // Because comma is not a command group
    check_input as *const (),
    false,
    1
);
pub fn new( combinator: impl Into<Option<Combinator>>, check_input_fn: CheckStreamFn, validate_parsed: bool, length: u8, ) -> Self

Constructs new GroupDeterminer.

Example:
extern crate join_impl;
extern crate syn;

use syn::Token;
use syn::parse::ParseStream;
use join_impl::chain::group::GroupDeterminer;

fn check_input(input: ParseStream) -> bool { input.peek(Token![,]) }

let first_comma_determiner = GroupDeterminer::new(
    None, // Because comma is not a command group
    check_input,
    false,
    1
);
pub fn combinator(&self) -> Option<Combinator>

Returns type of group of GroupDeterminer.

pub fn check_input(&self, input: ParseStream<'_>) -> bool

Checks if input next tokens are of self group type.

pub fn check_parsed<T: Parse>(&self, input: TokenStream) -> bool

Checks already parsed tokens. In many cases it’s used to check if parsed tokens are valid expression. in this case we can say for sure that we found separator.

pub fn erase_input<'b>(&self, input: ParseStream<'b>) -> Result<ParseStream<'b>>

Used to parse length tokens of type TokenTree from input ParseStream.

pub fn len(&self) -> u8

Returns value of length field.

pub fn is_empty(&self) -> bool

Returns true if length is zero.