Module join_impl::parse::utils[][src]

Utils for join! macro parsing and code generation.

Functions

is_block_expr

Returns true if expr is {...}.

is_valid_expr

Returns true if given stream is valid Expr.

is_valid_stream

Returns true if given stream can be parsed as T.

parse_until

Parses input ParseStream until one of provided GroupDeterminer's check will be valid or it reaches end.

skip

Skips next item in ParseStream. Returns true in case of success.