All expression group definitions.
Macros
- define_
determiner_ with_ no_ group - Creates
GroupDeterminerwith noCombinatorand provided tokens. - define_
group_ determiner - Creates
GroupDeterminerwith given (Combinator=> tokens => length => ?Check parsed tokens? (optional bool)) - define_
group_ determiners - Creates
GroupDeterminerfor givenCombinators with provided tokens. - define_
tokens_ checker - Creates function which checks if
ParseStreamnext values are provided tokens.
Structs
- Action
Group Combinatorwith configuration.- Expr
Group ActionwithExprof type eitherProcess,InitialorErr.- Group
Determiner GroupDetermineris used to determine anyCombinatoror separator (for ex.,) inParseStream
Enums
- Application
Type ApplicationTypedefines two types of action:InstantandDeferred.Instantmeans that action will be applied instantly, deferred means that it will wait for all actions in current step to be finished.- Combinator
Combinatoris an enum of all possibleProcessExpr,ErrExprandInitialExproperations. Used to express group which was found in inputParseStream.- Move
Type MoveTypedefines nested combinator types.